==> haskell-word-wrap-0.5-194.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 word-wrap
version:              0.5
visibility:           public
id:                   word-wrap-0.5-6fKuMGuR3bG4X1sVAx8Q29
key:                  word-wrap-0.5-6fKuMGuR3bG4X1sVAx8Q29
license:              BSD-3-Clause
copyright:            2017 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
homepage:             https://github.com/jtdaugherty/word-wrap/
synopsis:             A library for word-wrapping
description:          A library for wrapping long lines of text.
category:             Text
abi:                  d024400a76cc0bf7c26b9e5a760b5ba9
exposed:              True
exposed-modules:      Text.Wrap
import-dirs:          /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-word-wrap
hs-libraries:         HSword-wrap-0.5-6fKuMGuR3bG4X1sVAx8Q29
depends:              base-4.18.2.1 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html:         /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-word-wrap-0.5-195-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 word-wrap
version:              0.5
visibility:           public
id:                   word-wrap-0.5-5HAZzpPFBfyDixSZSXciv9
key:                  word-wrap-0.5-5HAZzpPFBfyDixSZSXciv9
license:              BSD-3-Clause
copyright:            2017 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
homepage:             https://github.com/jtdaugherty/word-wrap/
synopsis:             A library for word-wrapping
description:          A library for wrapping long lines of text.
category:             Text
abi:                  fb74b1812d4b23eb4180991401dc95fa
exposed:              True
exposed-modules:      Text.Wrap
import-dirs:          /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-word-wrap
hs-libraries:         HSword-wrap-0.5-5HAZzpPFBfyDixSZSXciv9
depends:              base-4.18.2.1 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html:         /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
